@@ -5,14 +5,14 @@
 */
 
 #include "specialmailcollections.h"
-#include "specialmailcollectionssettings.h"
 #include "akonadi_mime_debug.h"
+#include "specialmailcollectionssettings.h"
 
-#include <specialcollectionattribute.h>
-#include <entitydisplayattribute.h>
-#include <collectionmodifyjob.h>
 #include <agentinstance.h>
+#include <collectionmodifyjob.h>
+#include <entitydisplayattribute.h>
 #include <servermanager.h>
+#include <specialcollectionattribute.h>
 
 #include <KLocalizedString>
 #include <Kdelibs4ConfigMigrator>
@@ -32,19 +32,12 @@ typedef SpecialMailCollectionsSettings Settings;
 
 Q_GLOBAL_STATIC(SpecialMailCollectionsPrivate, sInstance)
 
-static const char s_specialCollectionTypes[SpecialMailCollections::LastType][11] = {
-    "local-mail",
-    "inbox",
-    "outbox",
-    "sent-mail",
-    "trash",
-    "drafts",
-    "templates"
-};
+static const char s_specialCollectionTypes[SpecialMailCollections::LastType][11] =
+    {"local-mail", "inbox", "outbox", "sent-mail", "trash", "drafts", "templates"};
 
 static const int s_numTypes = sizeof s_specialCollectionTypes / sizeof *s_specialCollectionTypes;
 
-static inline QByteArray enumToType(SpecialMailCollections::Type value)
+static inline QByteArray enumToByteArray(SpecialMailCollections::Type value)
 {
     return s_specialCollectionTypes[value];
 }
@@ -92,17 +85,17 @@ SpecialMailCollections *SpecialMailCollections::self()
 
 bool SpecialMailCollections::hasCollection(Type type, const AgentInstance &instance) const
 {
-    return SpecialCollections::hasCollection(enumToType(type), instance);
+    return SpecialCollections::hasCollection(enumToByteArray(type), instance);
 }
 
 Collection SpecialMailCollections::collection(Type type, const AgentInstance &instance) const
 {
-    return SpecialCollections::collection(enumToType(type), instance);
+    return SpecialCollections::collection(enumToByteArray(type), instance);
 }
 
 bool SpecialMailCollections::registerCollection(Type type, const Collection &collection)
 {
-    return SpecialCollections::registerCollection(enumToType(type), collection);
+    return SpecialCollections::registerCollection(enumToByteArray(type), collection);
 }
 
 bool SpecialMailCollections::unregisterCollection(const Collection &collection)
@@ -116,12 +109,12 @@ bool SpecialMailCollections::unregisterCollection(const Collection &collection)
 
 bool SpecialMailCollections::hasDefaultCollection(Type type) const
 {
-    return SpecialCollections::hasDefaultCollection(enumToType(type));
+    return SpecialCollections::hasDefaultCollection(enumToByteArray(type));
 }
 
 Collection SpecialMailCollections::defaultCollection(Type type) const
 {
-    return SpecialCollections::defaultCollection(enumToType(type));
+    return SpecialCollections::defaultCollection(enumToByteArray(type));
 }
 
 void SpecialMailCollections::verifyI18nDefaultCollection(Type type)
@@ -155,7 +148,7 @@ void SpecialMailCollections::verifyI18nDefaultCollection(Type type)
         if (collection.hasAttribute<Akonadi::EntityDisplayAttribute>()) {
             if (collection.attribute<Akonadi::EntityDisplayAttribute>()->displayName() != defaultI18n) {
                 collection.attribute<Akonadi::EntityDisplayAttribute>()->setDisplayName(defaultI18n);
-                auto *job = new Akonadi::CollectionModifyJob(collection, this);
+                auto job = new Akonadi::CollectionModifyJob(collection, this);
                 connect(job, &Akonadi::CollectionModifyJob::result, this, &SpecialMailCollections::slotCollectionModified);
             }
         }
